﻿$ErrorActionPreference = 'Stop';

# Stop and remove the old service name.
if ($null -ne (Get-Service -Name "UEFS Docker Volume Plugin" -ErrorAction SilentlyContinue)) {
  Stop-Service -Name "UEFS Docker Volume Plugin"
  sc.exe delete "UEFS Docker Volume Plugin"
}

# In case this is a force install, stop the existing service.
if ($null -ne (Get-Service -Name "UEFS Service" -ErrorAction SilentlyContinue)) {
  Stop-Service -Name "UEFS Service"
}

# Install UEFS.
Get-ChocolateyUnzip -FileFullPath "$(Split-Path -Parent $MyInvocation.MyCommand.Definition)\\uefs.zip" -Destination "$env:ProgramFiles\UEFS" -PackageName "UEFS"

# Shim the UEFS binary onto the PATH.
Install-BinFile -Name "uefs" -Path "$env:ProgramFiles\UEFS\uefs.exe"

# Install the plugin service.
$ExistingService = (Get-Service -Name "UEFS Service" -ErrorAction SilentlyContinue)
if ($null -ne $ExistingService) {
  $ExistingPath = (Get-WmiObject win32_Service | ? { $_.Name -eq "UEFS Service" }).PathName
  if ($ExistingPath -ne "$env:ProgramFiles\UEFS\uefs-daemon-service.exe") {
    Write-Host "Need to update binary path to UEFS Service, reinstalling service..."
    sc.exe delete "UEFS Service"
  }
}
if ($null -eq (Get-Service -Name "UEFS Service" -ErrorAction SilentlyContinue)) {
  New-Service -Name "UEFS Service" `
    -BinaryPathName "$env:ProgramFiles\UEFS\uefs-daemon-service.exe" `
    -DisplayName "UEFS Service" `
    -Description "Provides UEFS services, including volume services to the local Docker Engine." `
    -StartupType Automatic
}

# Start the service.
try {
  Start-Service -Name "UEFS Service"
} catch {
  Write-Warning "Unable to start UEFS service after installation. Use 'Start-Service -Name `"UEFS Service`"' to manually start it."
}